@@ -11,7 +11,7 @@ import traceback
 from string import Template
 from os.path import expanduser
 
-version = '0.3.0'
+version = '0.3.2'
 
 logger = logging.getLogger("ppagent")
 config_home = expanduser("~/.ppagent/")
@@ -172,7 +172,7 @@ class CGMiner(Miner):
             # set the next time it should run
             conf['next_run'] += conf['interval']
 
-        if 'hashrate' in self.collectors and now >= self.collectors['hashrate']['next_run']:
+        if mhs and 'hashrate' in self.collectors and now >= self.collectors['hashrate']['next_run']:
             conf = self.collectors['hashrate']
             self.queue.append([self.worker, 'hashrate', mhs, now])
 
@@ -227,7 +227,7 @@ class CGMiner(Miner):
             mhs = [round(now['Total MH'] - last['Total MH'], 3)
                    for now, last in zip(data['DEVS'], self.last_devs)]
         else:
-            mhs = [d['MHS 5s'] for d in data['DEVS']]
+            mhs = [d.get('MHS 5s') for d in data['DEVS'] if 'MHS 5s' in d]
         self.last_devs = data['DEVS']
         return mhs, temps, details
 
@@ -361,7 +361,7 @@ class AgentSender(object):
                 # recieve, just wait till next loop to send
                 ret = self.recieve()
                 if ret is None or ret.get('error', True) is not None:
-                    logger.warn("Recieved failure result '{}' from the server!"
+                    logger.warn("Recieved failure result '{0}' from the server!"
                                 .format(ret))
                     break
                 farthest = i + 1
